#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-marshalling
version:              2.3.1
visibility:           public
id:                   hslua-marshalling-2.3.1-HkFfVrOiUD5G0QApEZMIXZ
key:                  hslua-marshalling-2.3.1-HkFfVrOiUD5G0QApEZMIXZ
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2024 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Marshalling of values between Haskell and Lua.
description:
    Provides functions to marshal values from Haskell
    to Lua, and /vice versa/.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  c0c25df1fb00d098b0756a18f728dbad
exposed:              True
exposed-modules:
    HsLua.Marshalling HsLua.Marshalling.Peek HsLua.Marshalling.Peekers
    HsLua.Marshalling.Push HsLua.Marshalling.Userdata

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-marshalling-2.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-marshalling-2.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-marshalling-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-marshalling
hs-libraries:         HShslua-marshalling-2.3.1-HkFfVrOiUD5G0QApEZMIXZ
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    hslua-core-2.3.2-ABXu6faa3PJ6iIiStpPDNc mtl-2.3.1 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-marshalling/html/hslua-marshalling.haddock

haddock-html:         /usr/share/doc/haskell-hslua-marshalling/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

